// *******************************************************************
// MARC - Memory Architecture for Reconfigurable Computers
// "marcdefs.v" ist die Konfigurationsdatei fr MARC
// Die durch den Benutzer vernderbaren Parameter sind mit "**" markiert.
// *******************************************************************

`ifdef MARCDEFS_V
`else
`define MARCDEFS_V

`timescale 1ns/10ps

// ChipScope fr i960 und SRAM einschalten
//`define MARC_ILA

// Slave-Mode Interface
// vereinfachtes Interface & Adressierung (nur ADDRESSED und IRQ,
// LBTERML, LREADYIL etc.
`define SLAVE_SIMPLE // **

// Allgemeine Parameter
`define NUM_CACHEPORTS  0 // ** keinen Cache verwenden
`define NUM_STREAMPORTS 0 // ** keine Streams verwenden
`define DATA_WIDTH 32
`define ADDR_WIDTH 24
`define NUM_QBSR 2        // Vierfach-Block SelectRam+ 512*8 Bit; 2er-Potenz
`define NUM_TECHMODS 1    // **

// Bitvektor, Benutze BlockRam fr StreamPort Nr. n...0
`define FIFO_BLOCKRAM 0 // ** dezimal angeben!

// Wird SRAM verwendet? (Techmod, FIFO)
//`define MARC_SRAM // **

// Anzahl der verschiedenen Technologiemodule
`define NUM_TECHMOD_SRAM 0 // **
`define NUM_TECHMOD_I960 0 // **
`define NUM_TECHMOD_NULL 0 // **

// Adressen der Technologiemodule **
// Format: {TECHMOD[n], TECHMOD[n-1], ... , TECHMOD[0]}
//`define ADDR_TECHMODS {ADDRT[22] == 1'b1, ADDRT[22:20] == 3'b011, ADDRT[22:20] == 3'b010, ADDRT[22:20] == 3'b001, ADDRT[22:20] == 3'b000}
`define ADDR_TECHMODS {1'b1}

// Non-cacheable Adressen **
// Format: Boolescher Ausdruch mit ADDRN[...]
//`define NON_CACHEABLE 1'b1
//`define NON_CACHEABLE ((ADDRN[21:0] > 22'b0110000000000000000000) && (ADDRN[21:0] < 22'b1010000000000000000000))
//`define NON_CACHEABLE (ADDRN == 'h40002) | (ADDRN == 'h40004)
`define NON_CACHEABLE 1'b0

// Von den folgenden Konfigurationen ist jeweils eine zu aktivieren **
// Konfiguration 128 Cachelines zu 8 Worten
/*
`define CONF_128_8
`define CONF_64_16
`define CONF_32_32
`define NUM_CACHELINES 128      // Durch 4 teilbar
`define CACHELINE_ADDR_WIDTH 6  // {Zusammen
`define CACHELINE_WIDTH 3       // {9
`define CACHELINE_SIZE 8        // = 512*2/`NUM_CACHELINES
*/
// Konfiguration 64 Cachelines zu 16 Worten
/*
`define CONF_64_16
`define CONF_32_32
`define NUM_CACHELINES 64       // Durch 4 teilbar
`define CACHELINE_ADDR_WIDTH 5  // {Zusammen
`define CACHELINE_WIDTH 4       // {9
`define CACHELINE_SIZE 16       // = 512*2/`NUM_CACHELINES
*/
// Konfiguration 32 Cachelines zu 32 Worten

`define CONF_32_32
`define NUM_CACHELINES 32       // Durch 4 teilbar
`define CACHELINE_ADDR_WIDTH 4  // {Zusammen
`define CACHELINE_WIDTH 5       // {9
`define CACHELINE_SIZE 32       // = 512*2/`NUM_CACHELINES

// Burstzugriffe selektiv abschalten **
//`define CACHE_SINGLE_READ
//`define CACHE_SINGLE_WRITE
//`define STREAM_SINGLE_READ
//`define STREAM_SINGLE_WRITE

// Ende des benutzerkonfigurierbaren Bereiches
`endif
